@@ -456,9 +456,6 @@ def cutmix(batch, label, prob=1.0, dimension=256, n_classes=1, n_labels=None):
     tf.Tensor
         A batch of images with Cutmix applied
     """
-    #P = tf.cast(tf.random.uniform([], 0, 1) < prob, tf.int32)
-    #if (P == 0):
-    #    return batch, label  # no action
 
     DIM = dimension
     rank = len(batch.shape) - 2
@@ -513,7 +510,7 @@ def cutmix(batch, label, prob=1.0, dimension=256, n_classes=1, n_labels=None):
     return image2, label2
 
 
-def mixup(batch, label, prob=1.0, dimension=256, n_classes=1):
+def mixup(batch, label, prob=1.0, dimension=256, n_classes=1, n_labels=None):
     """
     Mixup randomly mixes data from two samples
 
@@ -539,9 +536,6 @@ def mixup(batch, label, prob=1.0, dimension=256, n_classes=1):
     tf.Tensor
         A batch of images with Mixup applied
     """
-    #P = tf.cast(tf.random.uniform([], 0, 1) < prob, tf.int32)
-    #if (P == 0):
-        #return batch, label  # no action
 
     DIM = dimension
     CLASSES = n_classes
@@ -567,7 +561,11 @@ def mixup(batch, label, prob=1.0, dimension=256, n_classes=1):
     # RESHAPE HACK SO TPU COMPILER KNOWS SHAPE OF OUTPUT TENSOR (maybe use Python typing instead?)
     image2 = tf.reshape(tf.stack(imgs), (batch_size, DIM, DIM, 3)) if rank == 2 else tf.reshape(tf.stack(imgs), (
     batch_size, DIM, DIM, DIM, 3))
-    label2 = tf.reshape(tf.stack(labs), (batch_size, CLASSES))
+
+    if n_labels:
+        label2 = tf.reshape(tf.stack(labs), (batch_size, n_labels))
+    else:
+        label2 = tf.reshape(tf.stack(labs), (batch_size, n_classes))
     return image2, label2
 
 
